@@ -16,7 +16,9 @@ Usage::
     session_client: OutpostsClient = session.client("outposts")
     ```
 """
-from mypy_boto3_outposts.client import OutpostsClient, OutpostsClient as Client
+from mypy_boto3_outposts.client import OutpostsClient
+
+Client = OutpostsClient
 
 
 __all__ = ("Client", "OutpostsClient")
